<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl">
<context>
    <name>EditHatch</name>
    <message>
        <location filename="../EditHatch.js" line="+61"/>
        <source>Choose hatch</source>
        <translation>Proszę wskazać kreskowanie</translation>
    </message>
    <message>
        <location filename="../EditHatchInit.js" line="+2"/>
        <source>Edit &amp;Hatch</source>
        <translation>Edytuj &amp;kreskowanie</translation>
    </message>
</context>
<context>
    <name>EditText</name>
    <message>
        <source>Choose text</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Wybierz tekst</translation>
    </message>
    <message>
        <source>Edit Te&amp;xt</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Edytuj tekst</translation>
    </message>
    <message>
        <source>Edit text</source>
        <translatorcomment>--exact match--
--file: designer_pl.ts--
Modyfikuj tekst</translatorcomment>
        <translation type="obsolete">Modyfikuj tekst</translation>
    </message>
</context>
</TS>
